Fix typo in exception name (UnimplementedError should be
NotImplementedError) found by Neil Norwitz's PyChecker.
diff --git a/Lib/smtpd.py b/Lib/smtpd.py
index b5db3b0..fffc229 100755
--- a/Lib/smtpd.py
+++ b/Lib/smtpd.py
@@ -38,7 +38,7 @@
 # has a hierarchy of classes which implement the backend functionality for the
 # smtpd.  A number of classes are provided:
 #
 #   SMTPServer - the base class for the backend.  Raises an UnimplementedError
 #   if you try to use it.
 #
 #   DebuggingServer - simply prints each message it receives on stdout.
@@ -309,7 +309,7 @@
         otherwise it returns the desired response string in RFC 821 format.
 
         """
-        raise UnimplementedError
+        raise NotImplementedError
 
 
 class DebuggingServer(SMTPServer):
@@ -38,7 +38,7 @@
 # smtpd.  A number of classes are provided:
 #
-#   SMTPServer - the base class for the backend.  Raises an UnimplementedError
+#   SMTPServer - the base class for the backend.  Raises NotImplementedError
 #   if you try to use it.
 #